@@ -75,6 +75,16 @@ def create_lyric_outro(deezer_artist_id, lyric_outro_repeat,  arr_comp, time_o=5
         path_video = None
         pass
     return path_video
+def create_image(list_comp_data,path_img, t=0):
+    arr_comps = []
+    for comp_data in list_comp_data:
+        comp_data["job_id"] = 1
+        comp_data["mf_server"] = ""
+        arr_comps.append(Component.convert(comp_data).make())
+
+    CompositeVideoClip(arr_comps).save_frame(path_img,t)
+    return path_img
+
 def create_video(list_comp_data, path_video, job_id, mf_server):
     print('get list')
     intro_time=10
